@@ -1,6 +1,7 @@
 import functools
 import weakref
-from typing_extensions import Any, Callable, Protocol, Type, TypeVar, Union, cast
+from typing import Any, Callable, Type, TypeVar, Union, cast
+from typing_extensions import Protocol
 '''
 Typing this library correctly is impossible right now.
 
